@@ -37,7 +37,7 @@ class MenuEditor:
 
 	def __loadMenus(self):
 		self.applications = Menu()
-		self.applications.tree = gmenu.lookup_tree('applications.menu', gmenu.FLAGS_SHOW_EMPTY|gmenu.FLAGS_INCLUDE_EXCLUDED|gmenu.FLAGS_INCLUDE_NODISPLAY)
+		self.applications.tree = gmenu.lookup_tree('applications.menu', gmenu.FLAGS_SHOW_EMPTY|gmenu.FLAGS_INCLUDE_EXCLUDED|gmenu.FLAGS_INCLUDE_NODISPLAY|gmenu.FLAGS_SHOW_ALL_SEPARATORS)
 		self.applications.visible_tree = gmenu.lookup_tree('applications.menu')
 		self.applications.path = os.path.join(util.getUserMenuPath(), self.applications.tree.get_menu_file())
 		if not os.path.isfile(self.applications.path):
@@ -47,7 +47,7 @@ class MenuEditor:
 		self.__remove_whilespace_nodes(self.applications.dom)
 
 		self.settings = Menu() 	 
-		self.settings.tree = gmenu.lookup_tree('settings.menu', gmenu.FLAGS_SHOW_EMPTY|gmenu.FLAGS_INCLUDE_EXCLUDED|gmenu.FLAGS_INCLUDE_NODISPLAY) 	 
+		self.settings.tree = gmenu.lookup_tree('settings.menu', gmenu.FLAGS_SHOW_EMPTY|gmenu.FLAGS_INCLUDE_EXCLUDED|gmenu.FLAGS_INCLUDE_NODISPLAY|gmenu.FLAGS_SHOW_ALL_SEPARATORS)
 		self.settings.visible_tree = gmenu.lookup_tree('settings.menu') 	 
 		self.settings.path = os.path.join(util.getUserMenuPath(), self.settings.tree.get_menu_file()) 	 
 		if not os.path.isfile(self.settings.path): 	 
@@ -315,6 +315,11 @@ class MenuEditor:
 			parent = parent.get_parent()
 			if parent == menu:
 				return False
+
+		#don't move a menu into itself
+		if new_parent == menu:
+			return False
+
 		#can't move between top-level menus
 		if self.__getMenu(menu) != self.__getMenu(new_parent):
 			return False
@@ -374,6 +379,9 @@ class MenuEditor:
 	def revertMenu(self, menu):
 		if not self.canRevert(menu):
 			return
+		#wtf happened here? oh well, just bail
+		if not menu.get_desktop_file_path():
+			return
 		self.__addUndo([menu,])
 		file_id = os.path.split(menu.get_desktop_file_path())[1]
 		path = os.path.join(util.getUserDirectoryPath(), file_id)
@@ -401,6 +409,8 @@ class MenuEditor:
 				else:
 					continue
 			elif item.get_type() == gmenu.TYPE_DIRECTORY:
+				if item.get_desktop_file_path() == None:
+					continue
 				file_path = os.path.join(util.getUserDirectoryPath(), os.path.split(item.get_desktop_file_path())[1])
 				if not os.path.isfile(file_path):
 					file_path = item.get_desktop_file_path()
